# Multi-Agent Reasoning Problem Solver (MAR-PS)

MAR-PS is a multi-agent reasoning problem solver. You build teams and they work together to solve the problems you give them.

You can work with them as a member of their team.

## TODO

### Features to add

- TODO: add tool support

- TODO: add streaming support

### Backends to add

- MLX-ENGINE (<https://github.com/lmstudio-ai/mlx-engine/>)

### Hard ones to add

- TODO: add support for multi-recipient messages

- TODO: add support for multi-message responses

NOTE: These will be VERY difficult to implement because every time an entity receives a message, it tries to reply. If you send a message to many entities, they will all try to reply.
